# Security Policy

## Supported Versions

| Version | Supported |
| ------- | ------------------ |
| latest | :white_check_mark: |

## Reporting a Vulnerability

If you discover a security vulnerability in pyvista-js, please report it responsibly.

**Please do not report security vulnerabilities through public GitHub issues.**

Instead, please report them via [GitHub's private vulnerability reporting](https://github.com/tkoyama010/pyvista-js/security/advisories/new).

Include as much of the following information as possible:

- Type of issue (e.g., code injection, cross-site scripting, etc.)
- Full paths of source file(s) related to the issue
- Steps to reproduce the issue
- Proof-of-concept or exploit code (if possible)
- Impact of the issue

We will acknowledge receipt of your report and work with you to understand and address the issue.
